/**
 ******************************************************************************
 *
 * @file        MG32_EXIC_Init.h
 *
 * @brief       This file is used to configure EXIC setting.
 *              Device : MG32F02A064
 *              Package: TSSOP20
 *
 * @par         Project
 *              MG32
 * @version     V0.20
 * @date        2020/12/08 13:28 (H File Generated Date)
 * @author      Megawin Software Center
 * @copyright   Copyright (c) 2020 Megawin Technology Co., Ltd.
 *              All rights reserved.
 *
 ******************************************************************************
 * @par         Disclaimer
 *      The Demo software is provided "AS IS"  without any warranty, either
 *      expressed or implied, including, but not limited to, the implied warranties
 *      of merchantability and fitness for a particular purpose.  The author will
 *      not be liable for any special, incidental, consequential or indirect
 *      damages due to loss of data or any other reason.
 *      These statements agree with the world wide and local dictated laws about
 *      authorship and violence against these laws.
 ******************************************************************************
 ******************************************************************************
 */

#ifndef _MG32_EXIC_Init_H
#define _MG32_EXIC_Init_H

#include "MG32_EXIC.H"
#include "MG32_EXIC_DRV.h"

// <<< Use Configuration Wizard in Context Menu >>>


/**
 ******************************************************************************
 *
 * @brief       EXIC Initial Configure - MG32F02A064 (TSSOP20-Package)
 *
 ******************************************************************************
 */
//<h> EXIC Initial Configure - MG32F02A064 (TSSOP20-Package)

//
//=============================  PA EXIC Setting  ==============================
//
//<e0> Enable EXIC PA initial.
//<i> Port PA external interrupt configuration enable.
    //<h> AND (KBI)
    //<i> Port PA AND mask setting for External KBI input.
        //<o1.16..31>AND Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PA AND mask bits. Each bit is used to disable(mask) or enable the related PAx input line.
        //<q5> AND unmatch enable
        //<i> External interrupt PA AND path signal inverse enable.
    //</h>
    //<h> OR (Interrupt)
    //<i> Port PA OR mask setting for External interrupt input.
        //<o1.0..15> OR  Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PA OR mask bits. Each bit is used to disable(mask) or enable the related PAx input line.
    //</h>
    //<h> Trigger mode
    //<i> Port PA pin edge/level event trigger setting.
        //<e2.17>  PA8
        //<i> External interrupt PA8 pin edge/level event trigger enable.
            //<o3.16..17> PIN8 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.21>  PA10
        //<i> External interrupt PA10 pin edge/level event trigger enable.
            //<o3.20..21> PIN10 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
    //</h>
    //<q4> Interrupt enable
    //<i> Port PA interrupt enable.
//</e>
#define CONF_ExicPAInit_EN           0
#define CONF_ExicPAInit_AndOrMask    0x00000000
#define CONF_ExicPAInit_Mask         0x00000000  
#define CONF_ExicPAInit_Mode         0x55555555
#define CONF_ExicPAInit_INT          0
#define CONF_ExicPAInit_AINV         0


//
//=============================  PB EXIC Setting  ==============================
//
//<e0> Enable EXIC PB initial.
//<i> Port PB external interrupt configuration enable.
    //<h> AND (KBI)
    //<i> Port PB AND mask setting for External KBI input.
        //<o1.16..31>AND Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PB AND mask bits. Each bit is used to disable(mask) or enable the related PBx input line.
        //<q5> AND unmatch enable
        //<i> External interrupt PB AND path signal inverse enable.
    //</h>
    //<h> OR (Interrupt)
    //<i> Port PB OR mask setting for External interrupt input.
        //<o1.0..15> OR  Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PB OR mask bits. Each bit is used to disable(mask) or enable the related PBx input line.
    //</h>
    //<h> Trigger mode
    //<i> Port PB pin edge/level event trigger setting.
        //<e2.1>  PB0
        //<i> External interrupt PB0 pin edge/level event trigger enable.
            //<o3.0..1> PIN0 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.3>  PB1
        //<i> External interrupt PB1 pin edge/level event trigger enable.
            //<o3.2..3> PIN1 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.5>  PB2
        //<i> External interrupt PB2 pin edge/level event trigger enable.
            //<o3.4..5> PIN2 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.7>  PB3
        //<i> External interrupt PB3 pin edge/level event trigger enable.
            //<o3.6..7> PIN3 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.17>  PB8
        //<i> External interrupt PB8 pin edge/level event trigger enable.
            //<o3.16..17> PIN8 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.19>  PB9
        //<i> External interrupt PB9 pin edge/level event trigger enable.
            //<o3.18..19> PIN9 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.21>  PB10
        //<i> External interrupt PB10 pin edge/level event trigger enable.
            //<o3.20..21> PIN10 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.23>  PB11
        //<i> External interrupt PB11 pin edge/level event trigger enable.
            //<o3.22..23> PIN11 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
    //</h>
    //<q4> Interrupt enable
    //<i> Port PB interrupt enable.
//</e>
#define CONF_ExicPBInit_EN           0
#define CONF_ExicPBInit_AndOrMask    0x00000000
#define CONF_ExicPBInit_Mask         0x00000000  
#define CONF_ExicPBInit_Mode         0x55555555
#define CONF_ExicPBInit_INT          0
#define CONF_ExicPBInit_AINV         0


//
//=============================  PC EXIC Setting  ==============================
//
//<e0> Enable EXIC PC initial.
//<i> Port PC external interrupt configuration enable.
    //<h> AND (KBI)
    //<i> Port PC AND mask setting for External KBI input.
        //<o1.16..31>AND Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PC AND mask bits. Each bit is used to disable(mask) or enable the related PCx input line.
        //<q5> AND unmatch enable
        //<i> External interrupt PC AND path signal inverse enable.
    //</h>
    //<h> OR (Interrupt)
    //<i> Port PC OR mask setting for External interrupt input.
        //<o1.0..15> OR  Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PC OR mask bits. Each bit is used to disable(mask) or enable the related PCx input line.
    //</h>
    //<h> Trigger mode
    //<i> Port PC pin edge/level event trigger setting.
        //<e2.1>  PC0
        //<i> External interrupt PC0 pin edge/level event trigger enable.
            //<o3.0..1> PIN0 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.3>  PC1
        //<i> External interrupt PC1 pin edge/level event trigger enable.
            //<o3.2..3> PIN1 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.9>  PC4
        //<i> External interrupt PC4 pin edge/level event trigger enable.
            //<o3.8..9> PIN4 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.11>  PC5
        //<i> External interrupt PC5 pin edge/level event trigger enable.
            //<o3.10..11> PIN5 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.13>  PC6
        //<i> External interrupt PC6 pin edge/level event trigger enable.
            //<o3.12..13> PIN6 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
    //</h>
    //<q4> Interrupt enable
    //<i> Port PC interrupt enable.
//</e>
#define CONF_ExicPCInit_EN           0
#define CONF_ExicPCInit_AndOrMask    0x00000000
#define CONF_ExicPCInit_Mask         0x00000000  
#define CONF_ExicPCInit_Mode         0x55555555
#define CONF_ExicPCInit_INT          0
#define CONF_ExicPCInit_AINV         0


//
//=============================  PE EXIC Setting  ==============================
//
//<e0> Enable EXIC PE initial.
//<i> Port PE external interrupt configuration enable.
    //<h> AND (KBI)
    //<i> Port PE AND mask setting for External KBI input.
        //<o1.16..31>AND Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PE AND mask bits. Each bit is used to disable(mask) or enable the related PEx input line.
        //<q5> AND unmatch enable
        //<i> External interrupt PE AND path signal inverse enable.
    //</h>
    //<h> OR (Interrupt)
    //<i> Port PE OR mask setting for External interrupt input.
        //<o1.0..15> OR  Mask  (0x0000 ~ 0xFFFF) <0x0000-0xFFFF>
        //<i> External interrupt PE OR mask bits. Each bit is used to disable(mask) or enable the related PEx input line.
    //</h>
    //<h> Trigger mode
    //<i> Port PE pin edge/level event trigger setting.
        //<e2.21>  PE10
        //<i> External interrupt PE10 pin edge/level event trigger enable.
            //<o3.20..21> PIN10 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
        //<e2.23>  PE11
        //<i> External interrupt PE11 pin edge/level event trigger enable.
            //<o3.22..23> PIN11 trigger event is <1=>Level <2=>Edge <3=> Dual-edge
            //<i> [1] Level : External input trigger by voltage level
            //<i> [2] Edge : External input trigger by single edge
            //<i> [3] Dual-edge : External input trigger by rising or falling edge
        //</e>
    //</h>
    //<q4> Interrupt enable
    //<i> Port PE interrupt enable.
//</e>
#define CONF_ExicPEInit_EN           0
#define CONF_ExicPEInit_AndOrMask    0x00000000
#define CONF_ExicPEInit_Mask         0x00000000  
#define CONF_ExicPEInit_Mode         0x55555555
#define CONF_ExicPEInit_INT          0
#define CONF_ExicPEInit_AINV         0


// <<< end of configuration section >>>

void EXIC_Init(void);


#endif  // _MG32_EXIC_Init_H
